import AbstractCodeGenerator from "./AbstractCodeGenerator";
import { code_generator_options, sdk_definition, sdk_definition_files, sdk_service_definition, sdk_service_definition_method_arg, sdk_service_definition_type, sdk_service_definition_type_field, sdk_service_definition_type_fields, sdk_service_type } from "./types";
import { GraphQLEnumType, GraphQLInputObjectType, GraphQLObjectType, GraphQLScalarType, GraphQLType, GraphQLUnionType, GraphQLInterfaceType } from "graphql";
export declare abstract class AbstractGraphQLSdkSourceCodeGenerator extends AbstractCodeGenerator {
    protected definition: any | undefined;
    protected readonly defaultVars: any;
    protected readonly envs: any;
    constructor({ vars, envs, ...options }: code_generator_options & {
        vars?: any;
        envs?: any;
    });
    protected buildEndpointFromSource(source: string): string;
    protected buildDefaultVars(): Promise<{
        [key: string]: any;
    }>;
    protected fetchSource(): Promise<void>;
    protected prepare(): Promise<void>;
    abstract getLanguage(): string;
    protected configureSdkDefinition(def: sdk_definition): Promise<void>;
    protected buildDynamicFiles(): Promise<sdk_definition_files>;
    protected buildDynamicFilesFromServiceDefAndVars(def: sdk_service_definition, vars: any, r: Function): Promise<{}>;
    protected buildVars(): Promise<{
        [key: string]: any;
    }>;
    protected buildStaticFilesFromStaticTemplates(): Promise<{
        [key: string]: string | true;
    }>;
    protected buildSdkServiceDefinition(): Promise<sdk_service_definition>;
    protected buildSdkServiceDefinitionTypes(def: sdk_service_definition): Promise<void>;
    protected buildSdkServiceDefinitionModels(def: sdk_service_definition): Promise<void>;
    protected buildSdkServiceDefinitionInputs(def: sdk_service_definition): Promise<void>;
    protected buildSdkServiceDefinitionQueries(def: sdk_service_definition): Promise<void>;
    protected buildSdkServiceDefinitionMutationQueries(def: sdk_service_definition): Promise<void>;
    protected buildSdkServiceDefinitionQueryQueries(def: sdk_service_definition): Promise<void>;
    protected sortObject(o: any): {};
    protected convertGraphQLTypeFields(types: {
        [key: string]: any;
    }): sdk_service_definition_type_fields;
    protected convertGraphQLTypeToField(type: GraphQLType): Omit<sdk_service_definition_type_field, 'name'>;
    protected convertGraphQLTypeToArg(type: GraphQLType): Omit<sdk_service_definition_method_arg, 'name'>;
    protected convertGraphQLTypeToReturnType(type: GraphQLType): Omit<sdk_service_definition_method_arg, 'name'>;
    protected convertGraphQLTypeToType(type: GraphQLType): Omit<sdk_service_definition_type, 'name'>;
    protected convertGraphQLType(type: GraphQLType): sdk_service_type;
    getPrimitiveTypeMapping(): {
        Int: string;
        String: string;
        BigInt: string;
        Boolean: string;
        Float: string;
        ID: string;
        unknown: string;
        AccountNumber: string;
        Byte: string;
        CountryCode: string;
        Currency: string;
        Cuid: string;
        Date: string;
        DateTime: string;
        DID: string;
        Duration: string;
        EmailAddress: string;
        GUID: string;
        Hexadecimal: string;
        HexColorCode: string;
        HSL: string;
        HSLA: string;
        IBAN: string;
        ISBN: string;
        IP: string;
        IPv4: string;
        IPv6: string;
        ISO8601Duration: string;
        JSON: string;
        JSONObject: string;
        JWT: string;
        Latitude: string;
        LocalDate: string;
        Locale: string;
        LocalEndTime: string;
        LocalTime: string;
        Long: string;
        Longitude: string;
        MAC: string;
        NegativeInt: string;
        NegativeFloat: string;
        NonEmptyString: string;
        NonNegativeInt: string;
        NonNegativeFloat: string;
        NonPositiveInt: string;
        NonPositiveFloat: string;
        ObjectID: string;
        PhoneNumber: string;
        Port: string;
        PositiveInt: string;
        PositiveFloat: string;
        PostalCode: string;
        RGB: string;
        RGBA: string;
        RoutingNumber: string;
        SafeInt: string;
        SemVer: string;
        Time: string;
        Timestamp: string;
        TimeZone: string;
        UnsignedInt: string;
        UnsignedFloat: string;
        URL: string;
        USCurrency: string;
        UtcOffset: string;
        UUID: string;
        Upload: string;
        Void: string;
        DateTimeISO: string;
        LocalDateTime: string;
        DeweyDecimal: string;
        LCCSubclass: string;
        IPCPatent: string;
    };
    mapTypeName(name: string): string;
    buildPrimitiveTypeMapping(type: GraphQLScalarType): sdk_service_type;
    buildEnumTypeMapping(type: GraphQLEnumType): sdk_service_type;
    buildUnionTypeMapping(type: GraphQLUnionType): sdk_service_type;
    buildInterfaceTypeMapping(type: GraphQLInterfaceType): sdk_service_type;
    buildObjectTypeMapping(type: GraphQLObjectType): sdk_service_type;
    buildInputObjectTypeMapping(type: GraphQLInputObjectType): sdk_service_type;
}
export default AbstractGraphQLSdkSourceCodeGenerator;
//# sourceMappingURL=AbstractGraphQLSdkSourceCodeGenerator.d.ts.map